@@ -58,8 +58,10 @@ class LogicRow:
         """ if starts with cascade, triggers cascade processing """
 
         self.row_sets = row_sets
-        if row_sets is not None:  # eg, for debug as in upd_order_shipped test
-            row_sets.add_processed(logic_row=self)  # used in commit logic
+        fixme_set_processed_in_init = False
+        if fixme_set_processed_in_init:  # ALS clone order - this makes order look processed (wrongly)
+            if row_sets is not None:  # eg, for debug as in upd_order_shipped test
+                row_sets.add_processed_logic(logic_row=self)  # used in commit logic
 
         rb = RuleBank()
         self.rb = rb
@@ -285,6 +287,7 @@ class LogicRow:
         parent_mapper = object_mapper(to_parent.row)
         parents_relationships = parent_mapper.relationships
         parent_role_name = None
+        parent_reln_to_child_db = None
         child = self.row
         for each_relationship in parents_relationships:  # eg, Payment has child PaymentAllocation
             if each_relationship.direction == sqlalchemy.orm.interfaces.ONETOMANY:  # PA
@@ -298,13 +301,15 @@ class LogicRow:
                                         to_parent.name +
                                         "> to Allocation: " + str(type(child)))
                     parent_role_name = parent_mapper.class_.__name__  # default TODO design review
+                    parent_role_name = each_relationship.back_populates
+                    parent_reln_to_child_db = each_relationship
         if parent_role_name is None:
             raise Exception("Missing relationship from Parent Provider: <"  +
                             to_parent.name +
                             "> to child Allocation: " + str(type(child)) + " of class: " + child.__class__.__name__)
         setattr(child, parent_role_name, to_parent.row)
         child_mapper = object_mapper(self.row)
-        parent_role_def = child_mapper.relationships.get(parent_role_name)
+        parent_role_def = child_mapper.relationships.get(parent_role_name)  # found Project, model has project
         for each_fk_attr in parent_role_def.local_columns:
             if getattr(self.row, each_fk_attr.name) is not None:
                 self.log(f'warning: {parent_role_name} ({each_fk_attr.name} not None... fixing')
@@ -457,19 +462,45 @@ class LogicRow:
                 changes.append(each_attr.key)
         return changes
 
-    def copy_children(self, copy_from: base, which_children: dict):
+    def copy_children(self, copy_from: base, which_children: (dict or list)):
         """
-        Event handler to copy multiple children types to self from copy_from children.
+        Useful in row event handlers to copy multiple children types to self from copy_from children.
+
+        child-spec := < ‘child-list-name’ | < ‘child-list-name = parent-list-name’ >
+        child-list-spec := [child-spec | (child-spec, child-list-spec)]
 
         Eg. RowEvent on Order
-            which = dict(OrderDetailList = None)
+            which = ["OrderDetailList"]
             logic_row.copy_children(copy_from=row.parent, which_children=which)
 
+        Eg, test/copy_children:
+            child_list_spec = [
+                ("MileStoneList",
+                    ["DeliverableList"]  # for each Milestone, get the Deliverables
+                ),
+                "StaffList"
+            ]
         """
-        # self.log("copy_children")
-        for item in which_children.items():
-            copy_from_list_name = item[0]
-            copy_to_list_name = item[1] if item[1] else copy_from_list_name
+        # self.log("copy_children")  # FIXME
+        which_children_list = which_children
+        if isinstance(which_children, dict):  # prefer lists, but handle dict (initial version)
+            which_children_list = []
+            for item in which_children.items():
+                child_spec = item[0]
+                if item[1]:
+                    child_spec += f' = {item[1]}'
+                which_children_list.append(child_spec)
+
+        for each_item in which_children_list:
+            child_spec = each_item
+            if type(each_item) is tuple:
+                child_spec = each_item[0]
+            copy_from_list_name = child_spec
+            copy_to_list_name = child_spec
+            equal_index = child_spec.find("=")
+            if equal_index > 0:
+                copy_to_list_name = child_spec[0, equal_index].strip()
+                copy_from_list_name = child_spec[equal_index:].strip()
             copy_from_children = getattr(copy_from, copy_from_list_name)
             child_count = 0
             my_mapper = object_mapper(self.row)
@@ -478,18 +509,19 @@ class LogicRow:
             for each_from_row in copy_from_children:
                 # self.log(f'copy_children: {copy_from_list_name}[{child_count}] = {each_from_row}')
                 each_from_logic_row = LogicRow(row=each_from_row, old_row=each_from_row,
-                                                ins_upd_dlt="*", nest_level=0,
-                                                a_session=self.session,
-                                                row_sets=None)
+                                               ins_upd_dlt="*", nest_level=0,
+                                               a_session=self.session,
+                                               row_sets=None)
                 new_copy_to_row = LogicRow(row=copy_to_class(), old_row=copy_to_class(),
-                                                ins_upd_dlt="ins",
-                                                nest_level=self.nest_level + 1,
-                                                a_session=self.session,
-                                                row_sets=self.row_sets)
+                                           ins_upd_dlt="ins",
+                                           nest_level=self.nest_level + 1,
+                                           a_session=self.session,
+                                           row_sets=self.row_sets)
                 new_copy_to_row.set_same_named_attributes(each_from_logic_row)
                 new_copy_to_row.link(to_parent=self)
                 new_copy_to_row.insert(reason="Copy Children " + copy_to_list_name)  # triggers rules...
-
+                if type(each_item) is tuple:
+                    new_copy_to_row.copy_children(each_from_row, each_item[1])
 
     def set_same_named_attributes(self, from_logic_row: 'LogicRow'):
         """
@@ -870,6 +902,8 @@ class LogicRow:
             self.constraints()
             self.parent_cascade_attribute_changes_to_children()  # child chaining (cascade changed parent references)
             self.parent_cascade_pk_change()  # actions - delete, nullify, prevent
+            if self.row_sets is not None:  # required for adjustment logic (see dragons)
+                self.row_sets.add_processed_logic(logic_row=self)  # used in commit logic
             self.row_events()
             if self.row_sets is not None:  # eg, for debug as in upd_order_shipped test
                 self.row_sets.remove_submitted(logic_row=self)
@@ -900,9 +934,12 @@ class LogicRow:
             self.formula_rules()
             self.adjust_parent_aggregates()
             self.constraints()
+        if self.row_sets is not None:  # required for adjustment logic (see dragons)
+            self.row_sets.add_processed_logic(logic_row=self)  # used in commit logic
             self.row_events()
         if self.row_sets is not None:  # eg, for debug as in upd_order_shipped test
-                self.row_sets.remove_submitted(logic_row=self)
+            self.row_sets.remove_submitted(logic_row=self)
+
 
     def delete(self, reason: str = None, row: base = None, do_not_adjust_list = None):
         """
@@ -929,6 +966,7 @@ class LogicRow:
             self.adjust_parent_aggregates(do_not_adjust_list=do_not_adjust_list)
             self.constraints()
             self.cascade_delete_children()
+            self.row_sets.add_processed_logic(logic_row=self)  # used in commit logic
 
 
 class ParentRoleAdjuster:
@@ -969,25 +1007,49 @@ class ParentRoleAdjuster:
             listeners do not guarantee order
             Failures were seen for OrderDetail first
                 It adjusted to the New Customer
-            Fix is defer adjustment logic iff the parent row is in the submitted list
+            Fix is defer adjustment chaining logic iff the parent row is in the submitted list
+                That is, the adjustment is done, but we don't run chaining logic
+
+            Examples:
+                upd_order_reuse - occurs half time, see listeners-bug_explore to force
+                test_add_order
+                    first, note OrderDetails are **sometimes** processed before Order (it varies!)
+                    it's easy when the order is first
+                    if OrderDetail is first then "debug_info" will see....
+                        do_defer_adjustment: True, is_parent_submitted: True, is_parent_row_processed: False
+                            adjustment occurs, but *not* the update() logic (since will occur when processed)
+                ApiLogicServer - place_order.py, scenario: Clone Existing Order
+                    the order is first (only), so requires do_defer_adjustment is false, so...
+                    do_defer_adjustment: False, is_parent_submitted: True, is_parent_row_processed: True
         """
         if self.parent_logic_row is None:  # save *only altered* parents (often does nothing)
             pass
             # self.child_logic_row.log("adjust not required for parent_logic_row: " + str(self))
         else:
             parent_logic_row = self.parent_logic_row
-            do_defer_adjustment = parent_logic_row.row_sets.is_submitted(parent_logic_row.row)
-            if parent_logic_row.row_sets.is_client_insert(parent_logic_row.row):
-                do_defer_adjustment = do_defer_adjustment  # FIXME - temp debug
-                self.child_logic_row.log("Adjustment deferral does not apply for *inserted* parent" + self.parent_role_name)
+            row_sets = parent_logic_row.row_sets
+            parent_row_debug = self.parent_logic_row.row
+            is_parent_submitted = parent_logic_row.row in row_sets.submitted_row
+            is_parent_row_processed = parent_logic_row.row in row_sets.processed_rows
+            do_defer_adjustment = is_parent_submitted and not is_parent_row_processed
+            if self.child_logic_row.name == 'OrderDetailXX':
+                self.child_logic_row.log(f'do_defer_adjustment: {do_defer_adjustment}'
+                                         f', is_parent_submitted: {is_parent_submitted}'
+                                         f', is_parent_row_processed: {is_parent_row_processed}')
+                debug_info = "target child defer adjustment check..."
             enable_deferred_adjusts = True
             if do_defer_adjustment and enable_deferred_adjusts:  # see dragon alert, above
-                self.child_logic_row.log("Adjustment deferred to parent " + self.parent_role_name)
+                self.parent_logic_row.log(f'Adjustment logic chaining deferred for this parent parent '
+                                          f'do_defer_adjustment: {do_defer_adjustment}'
+                                          f', is_parent_submitted: {is_parent_submitted}'
+                                          f', is_parent_row_processed: {is_parent_row_processed}, ' +
+                                          self.parent_role_name)
+                debug_info = "target child defer adjustment!"
             else:
-                if do_defer_adjustment:
+                if do_defer_adjustment:   # just for debug when enable_deferred_adjusts is false
                     self.child_logic_row.log("Adjustment deferred DISABLED (DEBUG ONLY!!) for parent" + self.parent_role_name)
-                is_do_not_adjust = self.parent_logic_row.is_in_list(do_not_adjust_list)
-                if is_do_not_adjust:
+                is_do_not_adjust_deleted_parent = self.parent_logic_row.is_in_list(do_not_adjust_list)
+                if is_do_not_adjust_deleted_parent:
                     self.child_logic_row.log(f'No adjustment on deleted parent: {self.parent_role_name}')
                 else:
                     parent_logic_row.ins_upd_dlt = "upd"
@@ -999,7 +1061,7 @@ class ParentRoleAdjuster:
         else:
             previous_parent_logic_row = self.previous_parent_logic_row
             if (previous_parent_logic_row.row_sets.is_submitted(previous_parent_logic_row.row)):
-                self.child_logic_row.log("Adjustment deferred for " + self.parent_role_name)
+                self.child_logic_row.log("Adjustment deferred for previous parent:" + self.parent_role_name)
             else:
                 current_session = self.child_logic_row.session
                 previous_parent_logic_row.ins_upd_dlt = "upd"
